from seven_jd.jd.api.base import RestApi

class VcItemProductAppliesFindRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ware_id = None
			self.ware_name = None
			self.state = None
			self.begin_time = None
			self.end_time = None
			self.page = None
			self.length = None

		def getapiname(self):
			return 'jingdong.vc.item.product.applies.find'

			








from seven_jd.jd.api.base import RestApi

class CarMerberStoreListStoreInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.storeMakeId = None
			self.distance = None
			self.pageNo = None
			self.pageSize = None
			self.lon = None
			self.sort = None
			self.lat = None
			self.platform = None
			self.storeLabelId = None

		def getapiname(self):
			return 'jingdong.car.merber.store.listStoreInfo'

			








from seven_jd.jd.api.base import RestApi

class VcAplsStockUpdateProdStockInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.vendorCode = None
			self.companyId = None
			self.stockRfId = None
			self.skuid = None
			self.stockNum = None

		def getapiname(self):
			return 'jingdong.vc.apls.stock.updateProdStockInfo'

			








from seven_jd.jd.api.base import RestApi

class SvcSettlementInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.appId = None
			self.page = None
			self.createTimeEnd = None
			self.clientIp = None
			self.createTimeBegin = None
			self.size = None

		def getapiname(self):
			return 'jingdong.svc.settlement.info'

			








from seven_jd.jd.api.base import RestApi

class DdPushRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.data = None
			self.type = None
			self.openId = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.dd.push'

			








from seven_jd.jd.api.base import RestApi

class DetectionImagesRedLineDetectBatchRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.timeZone = None
			self.key = None
			self.value = None
			self.detectItem = None
			self.imageUrl = None

		def getapiname(self):
			return 'jingdong.detection.imagesRedLineDetectBatch'

			








from seven_jd.jd.api.base import RestApi

class MiniappRefundRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.userId = None
			self.refundUuid = None
			self.isHalfRefund = None
			self.orderId = None
			self.refundAmount = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.miniapp.refund'

			





